==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/BuildOverridesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildOverridesFluent<A extends BuildOverridesFluent<A>> extends Fluent<A>{
  public Boolean getForcePull();
  public A withForcePull(Boolean forcePull);
  public Boolean hasForcePull();
  public A addToImageLabels(Integer index,ImageLabel item);
  public A setToImageLabels(Integer index,ImageLabel item);
  public A addToImageLabels(io.fabric8.openshift.api.model.config.v1.ImageLabel... items);
  public A addAllToImageLabels(Collection<ImageLabel> items);
  public A removeFromImageLabels(io.fabric8.openshift.api.model.config.v1.ImageLabel... items);
  public A removeAllFromImageLabels(Collection<ImageLabel> items);
  public A removeMatchingFromImageLabels(Predicate<ImageLabelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildImageLabels instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ImageLabel> getImageLabels();
  public List<ImageLabel> buildImageLabels();
  public ImageLabel buildImageLabel(Integer index);
  public ImageLabel buildFirstImageLabel();
  public ImageLabel buildLastImageLabel();
  public ImageLabel buildMatchingImageLabel(Predicate<ImageLabelBuilder> predicate);
  public Boolean hasMatchingImageLabel(Predicate<ImageLabelBuilder> predicate);
  public A withImageLabels(List<ImageLabel> imageLabels);
  public A withImageLabels(io.fabric8.openshift.api.model.config.v1.ImageLabel... imageLabels);
  public Boolean hasImageLabels();
  public A addNewImageLabel(String name,String value);
  public BuildOverridesFluent.ImageLabelsNested<A> addNewImageLabel();
  public BuildOverridesFluent.ImageLabelsNested<A> addNewImageLabelLike(ImageLabel item);
  public BuildOverridesFluent.ImageLabelsNested<A> setNewImageLabelLike(Integer index,ImageLabel item);
  public BuildOverridesFluent.ImageLabelsNested<A> editImageLabel(Integer index);
  public BuildOverridesFluent.ImageLabelsNested<A> editFirstImageLabel();
  public BuildOverridesFluent.ImageLabelsNested<A> editLastImageLabel();
  public BuildOverridesFluent.ImageLabelsNested<A> editMatchingImageLabel(Predicate<ImageLabelBuilder> predicate);
  public A addToNodeSelector(String key,String value);
  public A addToNodeSelector(Map<String,String> map);
  public A removeFromNodeSelector(String key);
  public A removeFromNodeSelector(Map<String,String> map);
  public Map<String,String> getNodeSelector();
  public <K,V>A withNodeSelector(Map<String,String> nodeSelector);
  public Boolean hasNodeSelector();
  public A addToTolerations(Integer index,Toleration item);
  public A setToTolerations(Integer index,Toleration item);
  public A addToTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A addAllToTolerations(Collection<Toleration> items);
  public A removeFromTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A removeAllFromTolerations(Collection<Toleration> items);
  public List<Toleration> getTolerations();
  public Toleration getToleration(Integer index);
  public Toleration getFirstToleration();
  public Toleration getLastToleration();
  public Toleration getMatchingToleration(Predicate<Toleration> predicate);
  public Boolean hasMatchingToleration(Predicate<Toleration> predicate);
  public A withTolerations(List<Toleration> tolerations);
  public A withTolerations(io.fabric8.kubernetes.api.model.Toleration... tolerations);
  public Boolean hasTolerations();
  public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withForcePull();
  public interface ImageLabelsNested<N> extends Nested<N>,ImageLabelFluent<BuildOverridesFluent.ImageLabelsNested<N>>{
    public N and();
    public N endImageLabel();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/BuildOverridesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildOverridesFluent<A extends BuildOverridesFluent<A>> extends Fluent<A>{
  public Boolean getForcePull();
  public A withForcePull(Boolean forcePull);
  public Boolean hasForcePull();
  public A addToImageLabels(int index,ImageLabel item);
  public A setToImageLabels(int index,ImageLabel item);
  public A addToImageLabels(io.fabric8.openshift.api.model.config.v1.ImageLabel... items);
  public A addAllToImageLabels(Collection<ImageLabel> items);
  public A removeFromImageLabels(io.fabric8.openshift.api.model.config.v1.ImageLabel... items);
  public A removeAllFromImageLabels(Collection<ImageLabel> items);
  public A removeMatchingFromImageLabels(Predicate<ImageLabelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildImageLabels instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ImageLabel> getImageLabels();
  public List<ImageLabel> buildImageLabels();
  public ImageLabel buildImageLabel(int index);
  public ImageLabel buildFirstImageLabel();
  public ImageLabel buildLastImageLabel();
  public ImageLabel buildMatchingImageLabel(Predicate<ImageLabelBuilder> predicate);
  public Boolean hasMatchingImageLabel(Predicate<ImageLabelBuilder> predicate);
  public A withImageLabels(List<ImageLabel> imageLabels);
  public A withImageLabels(io.fabric8.openshift.api.model.config.v1.ImageLabel... imageLabels);
  public Boolean hasImageLabels();
  public A addNewImageLabel(String name,String value);
  public BuildOverridesFluent.ImageLabelsNested<A> addNewImageLabel();
  public BuildOverridesFluent.ImageLabelsNested<A> addNewImageLabelLike(ImageLabel item);
  public BuildOverridesFluent.ImageLabelsNested<A> setNewImageLabelLike(int index,ImageLabel item);
  public BuildOverridesFluent.ImageLabelsNested<A> editImageLabel(int index);
  public BuildOverridesFluent.ImageLabelsNested<A> editFirstImageLabel();
  public BuildOverridesFluent.ImageLabelsNested<A> editLastImageLabel();
  public BuildOverridesFluent.ImageLabelsNested<A> editMatchingImageLabel(Predicate<ImageLabelBuilder> predicate);
  public A addToNodeSelector(String key,String value);
  public A addToNodeSelector(Map<String,String> map);
  public A removeFromNodeSelector(String key);
  public A removeFromNodeSelector(Map<String,String> map);
  public Map<String,String> getNodeSelector();
  public <K,V>A withNodeSelector(Map<String,String> nodeSelector);
  public Boolean hasNodeSelector();
  public A addToTolerations(int index,Toleration item);
  public A setToTolerations(int index,Toleration item);
  public A addToTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A addAllToTolerations(Collection<Toleration> items);
  public A removeFromTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A removeAllFromTolerations(Collection<Toleration> items);
  public List<Toleration> getTolerations();
  public Toleration getToleration(int index);
  public Toleration getFirstToleration();
  public Toleration getLastToleration();
  public Toleration getMatchingToleration(Predicate<Toleration> predicate);
  public Boolean hasMatchingToleration(Predicate<Toleration> predicate);
  public A withTolerations(List<Toleration> tolerations);
  public A withTolerations(io.fabric8.kubernetes.api.model.Toleration... tolerations);
  public Boolean hasTolerations();
  public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withForcePull();
  public interface ImageLabelsNested<N> extends Nested<N>,ImageLabelFluent<BuildOverridesFluent.ImageLabelsNested<N>>{
    public N and();
    public N endImageLabel();
    
  }
  
}
